Documentation
¶
Index ¶
- func WithEnterpriseEdition() testcontainers.CustomizeRequestOption
- func WithImage(image string) testcontainers.CustomizeRequestOption
- func WithLogLevel(logLevel string) testcontainers.CustomizeRequestOption
- func WithNamespace(namespace string) testcontainers.CustomizeRequestOption
- type AerospikeContainer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WithEnterpriseEdition ¶ added in v0.2.2
func WithEnterpriseEdition() testcontainers.CustomizeRequestOption
WithEnterpriseEdition() sets the image to the enterprise edition of Aerospike.
func WithImage ¶
func WithImage(image string) testcontainers.CustomizeRequestOption
WithImage sets the image for the Aerospike container.
func WithLogLevel ¶ added in v0.2.2
func WithLogLevel(logLevel string) testcontainers.CustomizeRequestOption
func WithNamespace ¶
func WithNamespace(namespace string) testcontainers.CustomizeRequestOption
WithNamespace sets the default namespace that is created when Aerospike starts. By default, this is set to "test".
Types ¶
type AerospikeContainer ¶
type AerospikeContainer struct {
testcontainers.Container
}
func RunContainer ¶
func RunContainer(ctx context.Context, opts ...testcontainers.ContainerCustomizer) (*AerospikeContainer, error)
RunContainer creates an instance of the Aerospike container type.
func (AerospikeContainer) ServicePort ¶
func (c AerospikeContainer) ServicePort(ctx context.Context) (int, error)
Port returns the port on which the Aerospike container is listening.
Click to show internal directories.
Click to hide internal directories.